@@ -12,26 +12,39 @@ c	(->  ---------------------------------------------
      	real*8  Kpilog  !2  K$_{ch}/\pi_{ch}=(Kpilog*log(ss+.069)+Kpicns)*exp(-8/s') where ss(GeV**2)= 
                         !   effective s. s'(GeV**2)=s - 4.63.  See also Kpicns.
         real*8  Kpicns  !2  See Kpilog. 0.077
-        real*8  Elund   !2   E $<$ Elund$\Rightarrow$  Lund M.C is used. in h-n. (IntModel='int1'). 
-                        !    If IntModel='int2' $\Rightarrow$    Gheisha is used. Elund can be as
-                        !    small as 4.99. (Default is 500. For NEXT 4.99).
-
-        real*8  Elund2  !2   Elund $<$ E $<$  Elund2 $\Rightarrow$   ad hoc model is used; Elund2 must
-                        !    be {\ \lower-1.2pt\vbox{\hbox{\rlap{$>$}\lower5pt\vbox{\hbox{$\sim$}}}}\
-                        !     }100, if Elund2 $<$     Elund3.   Defualt is Elund
-        real*8  Elund3  !2  Elund2$<$ E $<$  Elund3 $\Rightarrow$  New Lund Fritiof is used.
-                        !   Elund3 can be $<$     Elund2. If E $>$  Elund3, ad hoc model is used.
-                        !   Default is Elund.
+        real*8  Elund   !2   obsolete (from v6.0)
+c                  old def
+c        real*8  Elund   !2   E $<$ Elund$\Rightarrow$  Lund M.C is used. in h-n. (IntModel='int1'). 
+c                        !    If IntModel='int2' $\Rightarrow$    Gheisha is used. Elund can be as
+c                        !    small as 4.99. (Default is 500. For NEXT 4.99).
+        real*8  Elund2  !2  obsolete (from v6.0)
+c              old def
+c        real*8  Elund2  !2   Elund $<$ E $<$  Elund2 $\Rightarrow$   ad hoc model is used; Elund2 must
+c                        !    be {\ \lower-1.2pt\vbox{\hbox{\rlap{$>$}\lower5pt\vbox{\hbox{$\sim$}}}}\
+c                        !     }100, if Elund2 $<$     Elund3.   Defualt is Elund
+         real*8 Elund3   !2 obsolete  (from v6.0).
+c                old def
+c        real*8  Elund3  !2  Elund2$<$ E $<$  Elund3 $\Rightarrow$  New Lund Fritiof is used.
+c                        !   Elund3 can be $<$     Elund2. If E $>$  Elund3, ad hoc model is used.
+c                        !   Default is Elund.
 	real*8  Efermi  !2  If Kinetic E $<$ Efermi, Fermi Momentum is considered for Nucleus target.\\
 
-        character*16  IntModel   !1 interaction model.  If 'int1', Lund Fritiof/Nucrin/adhoc models are used
-                       ! for hadronic interactions.  If 'int2' Gheisha code is used for hadronic interactions,
-                       ! at low energies. (See, Elund?).
-                       !  If 'inclusive', an inclusive treatment is employed as given in Contrib/Inclusive.
-                       !  To make this work actually, INCLUSIVE in cosmos/Zcondc.h must be given a value of 1
-                       !  when making the cosmos library.  At execution time, InclusiveFile must be given
-                       !  the path to the xdist.d file. (normally in Contrib/Inclusive/xdist.d)
-                       !  The treatmen is one dimesional. May be used for neutrino calculations.
+        character*64  IntModel !1 Interaction model description. Usage was changed from v6.0. 
+                      !    One may list  code name and upper energy bound  for the code.
+                      ! E.g.  IntModel = '"dpmjet3"' ; to specify the dpmjet3 in the entire energy region
+                      !       IntModel = '"dpmjet3" 100 "nexus2" to specify dpmjet3 at < 100 GeV and nexus2 
+                      !        at E>100 GeV
+                      !       IntModel = '"nucrin" 5 "fritiof1.6" 500 "adhoc" to specify  Nucrin,
+                      !               fritiof1.6, and ad-hoc model in the respective energy region.
+c              next is old def.
+c        character*16  IntModel   !1 interaction model.  If 'int1', Lund Fritiof/Nucrin/adhoc models are used
+c                       ! for hadronic interactions.  If 'int2' Gheisha code is used for hadronic interactions,
+c                       ! at low energies. (See, Elund?).
+c                       !  If 'inclusive', an inclusive treatment is employed as given in Contrib/Inclusive.
+c                       !  To make this work actually, INCLUSIVE in cosmos/Zcondc.h must be given a value of 1
+c                       !  when making the cosmos library.  At execution time, InclusiveFile must be given
+c                       !  the path to the xdist.d file. (normally in Contrib/Inclusive/xdist.d)
+c                       !  The treatmen is one dimesional. May be used for neutrino calculations.
         character*100 InclusiveFile !2 The path to the inclusive data file, xdist.d. Default is
                        !   "../Contrib/Inclusive/xdist.d"
         real*8 SucPw   !2  In the 2nd, 3rd,.. collision of a nucleon inside a nucleus, the collision is 
@@ -54,11 +67,15 @@ c	(->  ---------------------------------------------
                        !  are treated as pi- in Fritiof, else they are treated by adhoc model as they are.
 
 c	<-)     -----------------------------
- 
+c            next are not input parameters.
+        integer nmdls
+        parameter (nmdls = 8)
+        character*16 RegMdls(nmdls)
+
         common /Zevhnp/ Cepic0, Cekaon, Ceneuc, Mudirp, Kpilog, Eta2Pi0,
      *         Kpicns,  Efermi, Elund, Elund2, Elund3, SucPw, MulLow, 
      *         LundPara(10), SucInt
-        common /Zevhnc/ InclusiveFile, IntModel 
+        common /Zevhnc/RegMdls, InclusiveFile, IntModel 
 c                 this should be in block common. 
 c        data  Cepic0/0.3d0/, Cekaon/0.d0/, Ceneuc/0.35d0/,
 c    *         Mudirp/1.d0/, Kpilog/0.0062/, Kpicns/0.077/,
