@@ -4,12 +4,21 @@ c           ***************************************************
 c        +U77 compliler option is needed
 c        for the HP compiler.
 c        
-#ifdef NEXT486
+#undef GENERIC
+
+#if defined DECALPHA
+#define GENERIC
+#elif defined PCLinux
+#define GENERIC
+#endif
+
+
+#if defined NEXT486
 c           ******************** next Absoft  fortran ***************
 c           the same one as sun/hp may be usable instead of this.
 c
        subroutine cgetLoginN(userid)
-        character*8userid
+        character*8 userid
  	integer getlogin,  intlogin
         pointer(pu, intlogin)
  	pu=getlogin()
@@ -26,7 +35,7 @@ c
 		target(i:i)=Cstring(i)
 	enddo
        end
-#elif defined DECALPHA
+#elif defined GENERIC
       subroutine cgetLoginN(userid)
       implicit none
       character*8 userid
