@@ -16,7 +16,51 @@ c        at skelton making time
 #include "Zmanagerp.h"      
 #include "Zmanager.h"      
 
+#undef  F90
+#undef FLUSH
+
+#if defined PCLinux
+#define FLUSH
+#define F90
+#elif defined Solaris
+#define FLUSH
+#elif defined NEXT486
+#define FLUSH
+#elif defined DECALPHA
+#define FLUSH
+#elif defined CF_AlphaLinux
+#define FLUSH
+#elif defined SGI
+#define FLUSH
+#endif
+
+#if defined FLUSH
+      character*120 fn
+      logical first
+      integer klena
+      save first, fn
+      data first/.true./
+      
+      if(first) then
+         first = .false.
+         fn = ' '
+         call cgetfname(SeedFile, fn)
+      else
+#if defined F90
+         open(SeedFileDev, file=fn(1:klena(fn)), 
+     *    form='formatted', position='append')
+#else
+         open(SeedFileDev, file=fn(1:klena(fn)), 
+     *    form='formatted', access='append')
+#endif
+      endif
+#endif
+
       write(SeedFileDev, *)  SeedSave, EventNo
+
+#if defined FLUSH
+      close(SeedFileDev)
+#endif
       end
 c     ****************************************************
 c          read iformation for initial random number at flesh time
